jwt_decoder library
Lightweight JWT token decoder with typed claim access and expiration checking.
Classes
- JwtDecoder
- Decodes JWT tokens without signature verification.
- JwtPayload
- Decoded JWT payload with typed claim access.
Lightweight JWT token decoder with typed claim access and expiration checking.